@@ -1,8 +1,6 @@
 """This plugin provides assert introspection. When the plugin is enabled
 and a test failure occurs, the traceback is displayed with extra context
-around the line in which the exception was raised. Simple variable
-substitution is also performed in the context output to provide more
-debugging information."""
+and debugging information around the line where the exception was raised."""
 from nose.plugins import Plugin
 from nose.pyversion import exc_to_unicode, force_unicode
 from nose.inspector import inspect_traceback
@@ -15,12 +13,12 @@ class FailureDetail(Plugin):
     def options(self, parser, env):
         """Register commmandline options."""
         parser.add_option(
-            "-d", "--detailed-errors", "--failure-detail",
-            action="store_true",
-            default=env.get('NOSE_DETAILED_ERRORS'),
-            dest="detailedErrors", help="Add detail to error"
+            "-d", "--detailed-errors", "--failure-detail", action="store_true",
+            default=env.get('NOSE_DETAILED_ERRORS'), dest="detailedErrors",
+            help="Add detail to error"
             " output by attempting to evaluate failed"
-            " asserts [NOSE_DETAILED_ERRORS]")
+            " asserts [NOSE_DETAILED_ERRORS]"
+        )
 
     def configure(self, options, conf):
         """Configure plugin."""
